--[[-------------------------------------------------------------+
|	AutoLog											|
|	--> Automatic combat log toggle						|
|	Author : Bouilloire @ EU - Elune						|
|	Contact : n.brulez<at>gmail.com						|
|	Last edited : 03/05/2009 18:00:36						|
+---------------------------------------------------------------]]

AutoLog = LibStub("AceAddon-3.0"):NewAddon("AutoLog", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("AutoLog")

local version = "1.03"




local raid_list = {
	["ULD"] = L["Ulduar"],
	["NAX"] = L["Naxxramas"],
	["EYE"] = L["The Eye of Eternity"],
	["OBS"] = L["The Obsidian Sanctum"],
	["VOA"] = L["Vault of Archavon"],
}

local options = {
	name = "AutoLog",
	handler = AutoLog,
	type = 'group',
	args = {
		enable = {
			type = "toggle",
			name = L["Enable auto logging"],
			desc = L["If unchecked, AutoLog will never enable Combat Logging"],
			get = "IsALenabled",
			set = "ToggleEnable",
			width = "double",
			order = 0,
		},
		curLogging = {
			type = "toggle",
			name = L["Logging state"],
			disabled = true,
			desc = L["Checked if combat logging is currently on"],
			get = "IsCurrentlyLogging",
			set = "setCurrLog",
			order = 1,
		},
		raids25 = {
			type = "multiselect",
			name = L["Heroic Raids (25)"],
			desc = L["Heroic raid instances where you want to do a combat log"],
			values = raid_list,
			tristate = false,
			set = "SetRaid25",
			get = "GetRaid25",
			order = 2,
		},
		raids10 = {
			type = "multiselect",
			name = L["Normal Raids (10)"],
			desc = L["Normal raid instances where you want to do a combat log"],
			values = raid_list,
			tristate = false,
			set = "SetRaid10",
			get = "GetRaid10",
			order = 3,
		},
	},
}

local defaults = {
	char = {
		enable = true,
		curLogging = false,
		raids25 = {
			["ULD"] = false,
			["NAX"] = false,
			["EYE"] = false,
			["OBS"] = false,
			["VOA"] = false,
		},
		raids10 = {
			["ULD"] = false,
			["NAX"] = false,
			["EYE"] = false,
			["OBS"] = false,
			["VOA"] = false,
		},
	},
}

function AutoLog:OnInitialize()
	LibStub("AceConfig-3.0"):RegisterOptionsTable("AutoLog", options)
	self.db = LibStub("AceDB-3.0"):New("AutoLog_DB", defaults)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("AutoLog", "AutoLog v" .. version)
	self:RegisterChatCommand("autolog", "ChatCommand")
	self:RegisterChatCommand("al", "ChatCommand")
end

function AutoLog:OnEnable()
	self:Print("AutoLog " .. version .. L[" loaded."])
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	AutoLog:CheckLog()
end

function AutoLog:OnDisable()
	self:Print(L["AutoLog Disabled"])
	self:UnregisterEvent("ZONE_CHANGED_NEW_AREA")
end

function AutoLog:ZONE_CHANGED_NEW_AREA()
	AutoLog:CheckLog()
end

function AutoLog:CheckLog()
	local area = strlower(GetRealZoneText())
	local goLog = false
	local difficulty = GetInstanceDifficulty()
	local raidKey = nil
	local isLogging = LoggingCombat()
	--self:Print("Current area : " .. area)
	if not self.db.char.enable then
		-- Add-on is disabled
		return
	end
	for k, v in pairs (raid_list) do
		--self:Print(k .. " : " .. v)
		if area == strlower(v) then
			raidKey = k
		end
	end
	if not raidKey then
		-- zone not in list
		goLog = false
	elseif difficulty == 1 then
		-- Normal mode
		goLog = self.db.char.raids10[raidKey]
	elseif difficulty == 2 then
		-- Heroic mode
		goLog = self.db.char.raids25[raidKey]
	end

	if goLog and not isLogging then
		self:Print(L["Combat logging turned on"])
	elseif isLogging and not goLog then
		self:Print(L["Combat logging turned off"])
	end
	self.db.char.curLogging = LoggingCombat(goLog)
end

function AutoLog:ChatCommand(input)
	if not input or input:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	else
		LibStub("AceConfigCmd-3.0").HandleCommand(AutoLog, "autolog", "AutoLog", input)
	end
end

function AutoLog:SetCurrLog(info,newValue)
	self.db.char.curLogging = newValue
end

function AutoLog:IsCurrentlyLogging(info)
	self.db.char.curLogging = LoggingCombat()
	return self.db.char.curLogging
end

function AutoLog:IsALenabled(info)
	return self.db.char.enable
end

function AutoLog:ToggleEnable(info, newValue)
	self.db.char.enable = newValue
	AutoLog:CheckLog()
end

function AutoLog:GetRaid25(info,raid)
	return self.db.char.raids25[raid]
end

function AutoLog:SetRaid25(info,raid,val)
	self.db.char.raids25[raid] = val
	AutoLog:CheckLog()
end

function AutoLog:GetRaid10(info,raid)
	return self.db.char.raids10[raid]
end

function AutoLog:SetRaid10(info,raid,val)
	self.db.char.raids10[raid] = val
	AutoLog:CheckLog()
end